# Weatherlink2pg

A very simple app to download weatherlink data into a postgresql database through API.

## usage

## Installation

```sh
pip install weatherlink2pg
```

## Usage

See help

```sh
weatherlink2pg --help
```
